function [positions, clockError] = IntpGreatCircle(pData, pSoundsourcePositions, pCombinationDetails, pStartEndPosition)
%LEASTSQUARES A sample function to write your own tracking algorithms
%
%   Parameters:
%       pData (struct):
%           Data structured by soundsource. The toa is already corrected
%           (e.g. doppler correction etc.)
%       pSoundsourcePositions (struct):
%           The soundsource positions [deg].
%       pCombinationDetails (table):
%           Contains all information of the current soundsource
%           combination.
%       pStartEndPosition (double, logical):
%           Set to false if it has not been passed by artoa. Contains the
%           desired start and end position as a matrix of row vectors.
%
%
%   Returns:
%       positions (double):
%           The calculated list of segment positions as a X x 2 column vector.
%       clockError (double):
%           The estimated clock error.


%% Calculate great circle track
[latTrack, lonTrack] = gcwaypts( ...
        pStartEndPosition(1, 1), ...
        pStartEndPosition(1, 2), ...
        pStartEndPosition(2, 1), ...
        pStartEndPosition(2, 2), ...
        (pData.combinationEnd - 1) - pData.combinationBegin ...
    );

positions = [latTrack, lonTrack];
clockError = NaN(size(positions, 1), 1);

return;

end